%define debug_package %{nil}
%define product_family Red Hat Enterprise Linux
%define variant_titlecase Server
%define variant_lowercase server
%define release_name Maipo
%define base_release_version 7
%define full_release_version 7.9
%define dist_release_version 7rhgs
#%%define beta Beta
%define dist .el%{dist_release_version}
# repo family ensures that productids have more fine versioning. beta,htb,dist
%define repo_family dist

Name:           redhat-release%{?variant_lowercase:-%{variant_lowercase}}
Version:        %{full_release_version}
Release:        15%{?dist}
Summary:        %{product_family}%{?variant_titlecase: %{variant_titlecase}} release file
Group:          System Environment/Base
License:        GPLv2
Provides:       redhat-release = %{version}-%{release}
Provides:       system-release = %{version}-%{release}
Provides:       system-release(releasever) = %{base_release_version}%{?variant_titlecase}
Source0:        redhat-release-%{?variant_lowercase:%{variant_lowercase}}-%{full_release_version}.tar.gz
Source1:        85-display-manager.preset
Source2:        90-default.preset
Source3:        redhat-release-productids-7.9-dist-20200715082108.tar.gz

%description
%{product_family}%{?variant_titlecase: %{variant_titlecase}} release files

%prep
%setup -q -n redhat-release-%{?variant_lowercase:%{variant_lowercase}}-%{full_release_version} -a 3

%install
rm -rf %{buildroot}

# create /etc
mkdir -p %{buildroot}/etc

# create /etc/system-release and /etc/redhat-release
echo "%{product_family}%{?variant_titlecase: %{variant_titlecase}} release %{full_release_version}%{?beta: %{beta}} (%{release_name})" > %{buildroot}/etc/redhat-release
ln -s redhat-release %{buildroot}/etc/system-release

# create /etc/os-release
cat << EOF >>%{buildroot}/etc/os-release
NAME="%{product_family}%{?variant_titlecase: %{variant_titlecase}}"
VERSION="%{full_release_version} (%{release_name})"
ID="rhel"
ID_LIKE="fedora"
VARIANT="%{variant_titlecase}"
VARIANT_ID="%{variant_lowercase}"
VERSION_ID="%{full_release_version}"
PRETTY_NAME="%{product_family}%{?variant_titlecase: %{variant_titlecase}} %{full_release_version}%{?beta: %{beta}} (%{release_name})"
ANSI_COLOR="0;31"
CPE_NAME="cpe:/o:redhat:enterprise_linux:%{full_release_version}:%{?beta:beta}%{!?beta:GA}%{?variant_lowercase::%{variant_lowercase}}"
HOME_URL="https://www.redhat.com/"
BUG_REPORT_URL="https://bugzilla.redhat.com/"

REDHAT_BUGZILLA_PRODUCT="%{product_family} %{base_release_version}"
REDHAT_BUGZILLA_PRODUCT_VERSION=%{full_release_version}
REDHAT_SUPPORT_PRODUCT="%{product_family}"
REDHAT_SUPPORT_PRODUCT_VERSION="%{full_release_version}%{?beta: %{beta}}"
EOF
# write cpe to /etc/system/release-cpe
echo "cpe:/o:redhat:enterprise_linux:%{full_release_version}:%{?beta:beta}%{!?beta:GA}%{?variant_lowercase::%{variant_lowercase}}" | tr [A-Z] [a-z] > %{buildroot}/etc/system-release-cpe

# create /etc/issue and /etc/issue.net
echo '\S' > %{buildroot}/etc/issue
echo 'Kernel \r on an \m' >> %{buildroot}/etc/issue
cp %{buildroot}/etc/issue %{buildroot}/etc/issue.net
echo >> %{buildroot}/etc/issue

# combine GPG keys
cat RPM-GPG-KEY-redhat-release-2 RPM-GPG-KEY-redhat-auxiliary > RPM-GPG-KEY-redhat-release
rm  RPM-GPG-KEY-redhat-release-2 RPM-GPG-KEY-redhat-auxiliary
cat RPM-GPG-KEY-redhat-beta-2 RPM-GPG-KEY-redhat-legacy-beta > RPM-GPG-KEY-redhat-beta
rm  RPM-GPG-KEY-redhat-beta-2 RPM-GPG-KEY-redhat-legacy-beta

# copy GPG keys
mkdir -p -m 755 %{buildroot}/etc/pki/rpm-gpg
for file in RPM-GPG-KEY* ; do
    install -m 644 $file %{buildroot}/etc/pki/rpm-gpg
done

# Copy Productids
mkdir -p -m 755 %{buildroot}/etc/pki/product-default
if [ -d redhat-release-productids-%{full_release_version}-%{repo_family}*/%{_arch} ]; then
    for pem in redhat-release-productids-%{full_release_version}-%{repo_family}*/%{_arch}/*.pem; do
        install -m 644 $pem %{buildroot}/etc/pki/product-default
    done
fi

# set up the dist tag macros
install -d -m 755 %{buildroot}/etc/rpm
cat >> %{buildroot}/etc/rpm/macros.dist << EOF
# dist macros.

%%rhel %{base_release_version}
%%dist %dist
%%el%{base_release_version} 1
EOF

# use unbranded docdir
mkdir -p -m 755 %{buildroot}/%{_docdir}/redhat-release
install -m 644 GPL %{buildroot}/%{_docdir}/redhat-release

# copy systemd presets
mkdir -p %{buildroot}/%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE1} %{buildroot}/%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE2} %{buildroot}/%{_prefix}/lib/systemd/system-preset/


%clean
rm -rf %{buildroot}

%files
%defattr(0644,root,root,0755)
/etc/redhat-release
/etc/system-release
%config /etc/os-release
%config /etc/system-release-cpe
%config(noreplace) /etc/issue
%config(noreplace) /etc/issue.net
/etc/pki/rpm-gpg/
/etc/rpm/macros.dist
%{_docdir}/redhat-release/*
%{_prefix}/lib/systemd/system-preset/*
/etc/pki/product-default

%changelog
* Mon Nov 30 2020 Sreenath G - 7.9-0.el7rhgs
- Building for RHGS 3.5.3 el7rhgs
- Resolves: rhbz#1901832

* Tue Sep 08 2020 Djordje Todorovic <dtodorov@redhat.com> - 7.9-5.el7_9
- Disable polkit (static service) from the install section
- Resolves: RHELBLD-2143

* Wed Jul 15 2020 Djordje Todorovic <dtodorov@redhat.com> - 7.9-4.el7
- Rebuild for 7.9 Z-stream
- Resolves: SPRHEL-4115

* Tue Jul 14 2020 Djordje Todorovic <dtodorov@redhat.com> - 7.9-3.el7
- Really comment out Beta macro for RHEL-7.9-GA
- Resolves: rhbz#1789793

* Tue Jul 07 2020 Djordje Todorovic <dtodorov@redhat.com> - 7.9-2.el7
- Rebuild for RHEL-7.9 RC
- Resolves: RHELBLD-1908

* Fri Apr 17 2020 Djordje Todorovic - 7.9-1.el7
- Bump for HTB ProductIDs
- Resolves: SPRHEL-3276

* Mon Jan 13 2020 Djordje Todorovic - 7.9-0.el7
- Bump for Beta ProductIDs
- Resolves rhbz#1789791

* Fri Nov 08 2019 Bohdan Khomutskyi - 7.8-1.el7.1
- Bump for HTB product IDs
- Resolves rhbz#1739201

* Fri Sep 06 2019 Jon Disnard <jdisnard@redhat.com> - 7.8-1.el7
- Bump for beta productids
- Related: rhbz#1739195

* Fri Aug 09 2019 Jon Disnard - 7.8-0.el7
- Bump for RHEL-7.8 Beta
- Resolves: rhbz#1739195

* Wed Jul 03 2019 Djordje Todorovic - 7.7-10.el7
- Fix Beta macro for RHEL-7.7-GA
- Resolves: rhbz#1663235

* Tue Jul 02 2019 Djordje Todorovic - 7.7-9.el7
- Build for RHEL-7.7 GA
- Resolves: rhbz#1663235

* Wed Jun 12 2019 Djordje Todorovic - 7.7-8.el7_7
- Build for RHEL-7.7 Z-stream
- Resolves: rhbz#1663234

* Thu Jun 06 2019 Djordje Todorovic - 7.7-7.el7
- Bump for RHEL-7.7-HTB
- Resolves: rhbz#1663234

* Thu Apr 11 2019 Djordje Todorovic - 7.7-6.el7
- Rebuilt to include actual beta ProductIDs
- Related bug: 1696181
- Resolves: rhbz#1669115

* Mon Apr 01 2019 Jon Disnard - 7.7-5.el7
- Rebuilt to move EULA to new source package
- Related: rhbz#1693820

* Thu Mar 28 2019 Djordje Todorovic <dtodorov@redhat.com> - 7.7-4.el7
- Rebuild to include fixed ProductIDs JIRA: RCM-53336
- Resolves: rhbz#1669115

* Thu Jan 24 2019 Jon Disnard <jdisnard@redhat.com> - 7.7-3.el7
- Enable nfs-client.target in default preset. rhbz#1316369

* Fri Jan 04 2019 Djordje Todorovic <dtodorov@redhat.com> - 7.7-2.el7
- use non z-stream versioning scheme
- Resolves: rhbz#1663233

* Fri Jan 04 2019 Djordje Todorovic <dtodorov@redhat.com> - 7.7-0.el7_6
- bump for 7.7 Beta
- Resolves: rhbz#1663233

* Mon Sep 24 2018 Caleigh Runge-Hottman <crungeho@redhat.com> - 7.6-4.el7_6
- bump for 7.6 z-stream
- Resolves: rhbz#1560862

* Fri Sep 21 2018 Lubos Kocman <lkocman@redhat.com> - 7.6-4.el7
- bump for 7.6 GA
- Resolves: rhbz#1560862

* Tue Sep 04 2018 Lubos Kocman <lkocman@redhat.com> - 7.6-3.el7
- fix product string for HTB in default productids
- Resolves: rhbz#1560862
- Relates: rhbz#1624309

* Thu Aug 23 2018 Pavel Niahodkin - 7.6-2.el7
- Rebuilt for 7.6 HTB.
- Resolves: rhbz#1560864

* Wed Aug 01 2018 Lubos Kocman <lkocman@redhat.com> - 7.6-1.el7
- Fix typo in rhel-autorelabel-mark.service
- Resolves: rhbz#1571689

* Fri Apr 13 2018 Lubos Kocman <lkocman@redhat.com> - 7.6-0.el7
- initial build for rhel-7.6 beta
- Resolves: rhbz#1560863

* Wed Feb 28 2018 Lubos Kocman <lkocman@redhat.com> - 7.5-8.el7
- return back lost presets opal-prd, hypervfcopyd
- Relates: rhbz#1549645
- Resolves: rhbz#1477991

* Thu Feb 22 2018 Lubos Kocman <lkocman@redhat.com> - 7.5-7.el7
- rebuild for GA (previous z-stream build is internal only)
- Resolves: rhbz#1477991

* Mon Feb 12 2018 Lubos Kocman <lkocman@redhat.com> - 7.5-1.el7_5
- rebuild for z-stream config
- JIRA: RCM-28295
- Resolves: rhbz#1477991

* Tue Feb 06 2018 Lubos Kocman <lkocman@redhat.com> - 7.5-6.el7
- add NetworkManager-wait-online.service to presets
- add forgotten rhel-domainname.service to presets
- add spice-vdagentd.socket to presets
- Resolves: rhbz#1540243

* Thu Feb 01 2018 Djordje Todorovic <dtodorov@redhat.com> - 7.5-5.el7
- bump version for HTB to fix  rhbz#1538957
- Resolves: rhbz#1540523

* Wed Jan 24 2018 Djordje Todorovic <dtodorov@redhat.com> - 7.5-4.el7
- bump version for HTB
- Resolves: rhbz#1538583

* Wed Nov 29 2017 Lubos Kocman <lkocman@redhat.com> - 7.5-3.el7
- provide actual beta productids
- Resolves: rhbz#1477988

* Wed Jun 28 2017 Lubos Kocman <lkocman@redhat.com> - 7.5-1.el7
- rollback of new package request (redhat-release). JIRA: RCM-25033
- Resolves: rhbz#1466854

* Wed Jun 28 2017 Lubos Kocman <lkocman@redhat.com> - 7.4-18.el7
- rebuild for GA
- Resolves: rhbz#1465919

* Wed Jun 21 2017 Lubos Kocman <lkocman@redhat.com> - 7.4-17.el7
- fix missing repo_family macro
- Resolves: rhbz#1461546

* Wed Jun 21 2017 Lubos Kocman <lkocman@redhat.com> - 7.4-16.el7
- provide more fine versioning of productid archive
- Resolves: rhbz#1461546

* Thu May 25 2017 Lubos Kocman <lkocman@redhat.com> - 7.4-15.el7
- supply new htb pems
- Resolves: rhbz#1434546

* Wed Apr 03 2017 Lubos Kocman <lkocman@redhat.com> - 7.4-13.el7
- Introduce VARIANT, VARIANT_ID to /etc/os-release
- Resolves: rhbz#1434546

* Mon Mar 13 2017 Jon Disnard <jdisnard@redhat.com> - 7.4-12.el7
- Fine grain versioning of product id source file. 
- Apply various rpm macros consistently
- Resolves: rhbz#1380694

* Mon Mar 06 2017 Lubos Kocman <lkocman@redhat.com> - 7.4-11.el7
- Enable rhsmcertd.service (default preset) Resolves: rhbz#1271839
- Enable lvm2-lvmpolld.socket in default preset Resolves: rhbz#1316307
- Enable brandbot.* by default in default preset. Resolves: rhbz#1359645

* Wed Oct 05 2016 Lubos Kocman <lkocman@redhat.com> - 7.4-0.el7
- Rebuilt for 7.4 Beta

* Wed Oct 05 2016 Jan Blazek <jblazek@redhat.com> - 7.3-7.el7_3.1
- Rebuilt for 7.3.z

* Tue Sep 27 2016 Jan Blazek <jblazek@redhat.com> - 7.3-7.el7
- Rebuild for GA

* Tue Aug 09 2016 Jan Blazek <jblazek@redhat.com> - 7.3-6.el7
- Enable virtlogd.socket in default.preset
- Resolves: #1325503

* Fri Jul 15 2016 Jan Blazek <jblazek@redhat.com> - 7.3-5.el7
- Remove 'Development Preview' from aarch64 productid
- Resolves: #1353823

* Tue Jun 28 2016 Jan Blazek <jblazek@redhat.com> - 7.3-4.el7
- Add opal-prd to default.preset
- Resolves: #1312446

* Mon Jun 06 2016 Jan Blazek <jblazek@redhat.com> - 7.3-3.el7
- Add initial-setup-reconfiguration to default.preset
- Resolves: #1342536

* Tue Jan 05 2016 Jan Blazek <jblazek@redhat.com> - 7.3-2.el7
- Bump for 7.3 Beta
- Resolves: #1295811

* Thu Oct 29 2015 Daniel Mach <dmach@redhat.com> - 7.2-9.el7_2.1
* Rebuild for 7.2.z

* Fri Oct 23 2015 Jan Blazek <jblazek@redhat.com> - 7.2-9.el7
- Make /etc/os-release a config file (without noreplace)
- Resolves: #1257142

* Tue Oct 20 2015 Jan Blazek <jblazek@redhat.com> - 7.2-8.el7
- Rebuild for GA

* Thu Sep 10 2015 Jan Blazek <jblazek@redhat.com> - 7.2-7.el7
- Add unbound-anchor.timer to default.preset
- Resolves: #1215645

* Fri Sep 04 2015 Jan Blazek <jblazek@redhat.com> - 7.2-6.el7
- Include correct RHEL 7.2 Beta certificates
- Resolves: #1259820

* Thu Jul 30 2015 Jan Blazek <jblazek@redhat.com> - 7.2-4.el7
- Add hypervfcopyd to default.preset
- Resolves: #1193616

* Thu Jul 23 2015 Jan Blazek <jblazek@redhat.com> - 7.2-3.el7
- Remove the Initial Setup units from the systemd preset file
- Resolves: #1215226

* Wed Jul 22 2015 Jan Blazek <jblazek@redhat.com> - 7.2-2.el7
- Specify Beta in PRETTY_NAME in /etc/os-release
- Resolves: #1224247

* Mon Jun 15 2015 Lubos Kocman <lkocman@redhat.com> - 7.2-1.el7
- Include default productids
- Bump for 7.2 Beta
- Resolves: #1080007

* Thu Feb 12 2015 Jan Blazek <jblazek@redhat.com> - 7.1-1.el7_1.1
- Rebuild for 7.1.z

* Mon Feb 02 2015 Jan Blazek <jblazek@redhat.com> - 7.1-1.el7
- Rebuild for GA

* Fri Jan 09 2015 Jan Blazek <jblazek@redhat.com> - 7.1-0.3.el7
- Specify Beta in /etc/os-release
- Resolves: #1177449

* Thu Sep 25 2014 Jan Blazek <jblazek@redhat.com> - 7.1-0.1.el7
- Rebuilt for 7.1 Beta

* Wed Apr 30 2014 Daniel Mach <dmach@redhat.com> - 7.0-1.el7_0.1
- Rebuild for 7.0.z

* Tue Apr  1 2014 Daniel Mach <dmach@redhat.com> - 7.0-1.el7
- Rebuild for GA

* Tue Feb 25 2014 Daniel Mach <dmach@redhat.com> - 7.0-0.12.el7
- Fix variant_titlecase macro usage

* Wed Feb 19 2014 Daniel Mach <dmach@redhat.com> - 7.0-0.11.el7
- Enable microcode.service by default

* Tue Feb 18 2014 Daniel Mach <dmach@redhat.com> - 7.0-0.10.el7
- Update EULA text

* Wed Feb 12 2014 Daniel Mach <dmach@redhat.com> - 7.0-0.9.el7
- Add systemd presets
- Resolves: #903690

* Fri Jan 24 2014 Daniel Mach <dmach@redhat.com> - 7.0-0.8.el7
- Mass rebuild 2014-01-24

* Wed Jan 15 2014 Daniel Mach <dmach@redhat.com> - 7.0-0.7
- Add ID_LIKE, HOME_URL and BUG_REPORT_URL fields to /etc/os-release
- Make /etc/os-release a config file

* Fri Dec 27 2013 Daniel Mach <dmach@redhat.com> - 7.0-0.6
- Mass rebuild 2013-12-27

* Fri Nov  8 2013 Daniel Mach <dmach@redhat.com> - 7.0-0.5
- Rebuild for Beta
